@@ -1,11 +1,21 @@
+get_observations <- function(json_parametros, url) {
+  action <- "API_getSampleObservationsFromDataset"
+  return(genericDownloadCall(json_parametros, url, action, 25, 600))
+}
+
+getDataWithVectorizer <- function(json_parametros, url) {
+  action <- "API_getDataWithVectorizer"
+  return(genericDownloadCall(json_parametros, url, action, 5, 300))
+}
+
+
 #'@title Request to the API, depending on the action provided
 #'@description Prepare the data to send it 'OpenBlender' API. This function is not used by users.
 #'@param json_parametros Request parameters
 #'@param url Url selected
 #'@return List of observations obtained with \link{dameRespuestaLlamado}.
 #'@keywords internal
-get_observations <- function(json_parametros, url) {
-  action <- "API_getSampleObservationsFromDataset"
+genericDownloadCall <- function(json_parametros, url, action, n_test_observations, slice_mult) {
   start <- Sys.time()
   if ("test_call" %in% attributes(json_parametros)$names && (json_parametros$test_call == 1 || json_parametros$test_call == "on")) {
     test_call <- 1
@@ -13,13 +23,13 @@ get_observations <- function(json_parametros, url) {
     test_call <- FALSE
   }
   if (test_call == 1) {
-    message("This is a TEST CALL, set \"test_call\" : \"off\" or remove to execute service.")
+    message("This is a TEST CALL, set \"test_call\"=\"off\" or remove to execute service.")
     data <- list(action = action, json = json_parametros)
     respuesta <- dameRespuestaLlamado(url, data)
     df_resp <- respuesta$sample
     t_universo <- 0
   } else {
-    json_parametros$tamano_bin <- 50
+    json_parametros$tamano_bin <- n_test_observations
     json_parametros$skip <- 0
     message("Downloading...")
     data <- list(action = action, json = json_parametros)
@@ -27,7 +37,7 @@ get_observations <- function(json_parametros, url) {
     t_universo <- respuesta$universe_size
     stop <- Sys.time()
     segundos <- ceiling(stop - start)
-    tam_pedazo <- as.integer(round(600 / as.integer(segundos), digits = 0))
+    tam_pedazo <- as.integer(round(slice_mult / as.integer(segundos), digits = 0))
     if(tam_pedazo < t_universo) {
       nums_pedazos <- ceiling(t_universo / tam_pedazo)
       if (nums_pedazos <= 0) {
@@ -36,22 +46,27 @@ get_observations <- function(json_parametros, url) {
       df_resp <- NULL
       secuencia <- seq(0, nums_pedazos - 1, by = 1)
       for (i in secuencia) {
-        json_parametros$tamano_bin <- tam_pedazo
-        json_parametros$skip <- tam_pedazo * i
-        data <- list(action = action, json = json_parametros)
-        respuesta <- dameRespuestaLlamado(url, data)
-        df <- respuesta$sample
-        if (is.null(df_resp)) {
-          df_resp <- df
-        } else {
-          df_resp <- rbind(df_resp, df)
-        }
-        avance <- round(((i) / nums_pedazos) * 100, digits = 2)
-        if (avance >= 100) {
-          message(paste(avance, "% completed."))
-        } else {
-          message(paste(avance, "%"))
-        }
+        tryCatch({
+          json_parametros$tamano_bin <- tam_pedazo
+          json_parametros$skip <- tam_pedazo * i
+          data <- list(action = action, json = json_parametros)
+          respuesta <- dameRespuestaLlamado(url, data)
+          df <- respuesta$sample
+          if (is.null(df_resp)) {
+            df_resp <- df
+          } else {
+            df_resp <- rbind(df_resp, df)
+          }
+          avance <- round(((i) / nums_pedazos) * 100, digits = 2)
+          if (avance >= 100) {
+            message(paste(avance, "% completed."))
+          } else {
+            message(paste(avance, "%"))
+          }
+        },
+        error = function(e){
+          message("Some observations could not be processed.")
+        })
       }
       if ("sample_size" %in% attributes(json_parametros)$names) {
         if (as.integer(json_parametros$sample_size) < nrow(df_resp)) {
